# LLM Interaction Log - 20250622_193645

## Input

### Arguments

No positional arguments

### Keyword Arguments
- model: `gpt-3.5-turbo`

#### Messages:
- Role: `user`
  Content: `Hello! What is the capital of India.`
- max_tokens: `50`

## Output

- Model: `gpt-3.5-turbo-0125`
- Completion: `The capital of India is New Delhi.`

### Usage Statistics
- Completion Tokens: `8`
- Prompt Tokens: `16`
- Total Tokens: `24`
